
# Google APIs common protos

TOOD: Add standard badges 

googleapis-common-protos contains the python classes generated from the common
protos in the [googleapis/api-common-protos](https://github.com/googleapis/api-common-protos) repository.